@@ -111,7 +111,7 @@ test_that("expectation are created properly with create_expectations_vector()",
     "# Testing type",
     "expect_type(\n  vec_3,\n  type = \"double\")",
     "# Testing values",
-    "expect_equal(\n  vec_3,\n  c(a1 = 10, a2 = 2, a3 = 4, b1 = 20, b2 = 1, b3 = 3, c1 = 2, c2 = 3,\nc3 = 30),\n  tolerance = 1e-4)",
+    "expect_equal(\n  vec_3,\n  c(a1 = 10, a2 = 2, a3 = 4, b1 = 20, b2 = 1, b3 = 3, c1 = 2, c2 = 3, \n    c3 = 30),\n  tolerance = 1e-4)",
     "# Testing names",
     "expect_equal(\n  names(vec_3),\n  c(\"a1\", \"a2\", \"a3\", \"b1\", \"b2\", \"b3\", \"c1\", \"c2\", \"c3\"),\n  fixed = TRUE)",
     "# Testing length",
@@ -134,7 +134,7 @@ test_that("expectation are created properly with create_expectations_vector()",
     "# Testing type",
     "expect_type(\n  vec_4,\n  type = \"list\")",
     "# Testing values",
-    "expect_equal(\n  vec_4,\n  list(a1 = 10, a2 = 2, a3 = 4, b1 = 20, b2 = 1, b3 = 3, c1 = 2, c2 = 3,\nc3 = 30))",
+    "expect_equal(\n  vec_4,\n  list(a1 = 10, a2 = 2, a3 = 4, b1 = 20, b2 = 1, b3 = 3, c1 = 2, c2 = 3, \n    c3 = 30))",
     "# Testing names",
     "expect_equal(\n  names(vec_4),\n  c(\"a1\", \"a2\", \"a3\", \"b1\", \"b2\", \"b3\", \"c1\", \"c2\", \"c3\"),\n  fixed = TRUE)",
     "# Testing length",
@@ -232,17 +232,19 @@ test_that("expectations are created returned by insertExpectationsAddin()", {
     stop("STOP NOW!")
   }
 
+  set_test_seed(1)
   expect_equal(
     insertExpectationsAddin("error_fn()", insert = FALSE),
     list(
       " ",
-      paste0("## Testing 'error_fn()'                                    ",
-             "                 ####"),
+      "## Testing 'error_fn()'                                                     ####",
       "## Initially generated by xpectr",
       "xpectr::set_test_seed(42)",
       "# Testing side effects",
-      paste0("expect_error(\n  xpectr::strip_msg(error_fn()),\n  xpectr::",
-             "strip(\"STOP NOW!\"),\n  fixed = TRUE)"),
+      "# Assigning side effects",
+      "side_effects_12655 <- xpectr::capture_side_effects(error_fn(), reset_seed = TRUE)",
+      "expect_equal(\n  xpectr::strip(side_effects_12655[['error']]),\n  xpectr::strip(\"STOP NOW!\"),\n  fixed = TRUE)",
+      "expect_equal(\n  xpectr::strip(side_effects_12655[['error_class']]),\n  xpectr::strip(c(\"simpleError\", \"error\", \"condition\")),\n  fixed = TRUE)",
       "## Finished testing 'error_fn()'                                            ####",
       " "
     ),
@@ -310,16 +312,18 @@ test_that("expectations are created returned by insertExpectationsAddin()", {
       "# Testing column values",
       paste0("expect_equal(\n  xpectr::smpl(long_df[[\"a\"]], n = 30),\n ",
              " c(0.93708, 0.28614, 0.64175, 0.5191, 0.73659, 0.13467, 0.70",
-             "506,\n0.45774, 0.71911, 0.93467, 0.25543, 0.97823, 0.11749, ",
-             "0.475,\n0.90403, 0.13871, 0.98889, 0.94667, 0.08244, 0.51421",
-             ", 0.3902,\n0.44697, 0.836, 0.7376, 0.81106, 0.00395, 0.83292",
-             ", 0.00733,\n0.20766, 0.61178),\n  tolerance = 1e-4)"),
+             "506, \n    0.45774, 0.71911, 0.93467, 0.25543, 0.97823, 0.11",
+             "749, 0.475, \n    0.90403, 0.13871, 0.98889, 0.94667, 0.0824",
+             "4, 0.51421, 0.3902, \n    0.44697, 0.836, 0.7376, 0.81106, 0",
+             ".00395, 0.83292, 0.00733, \n    0.20766, 0.61178),\n  tolera",
+             "nce = 1e-4)"),
       paste0("expect_equal(\n  xpectr::smpl(long_df[[\"b\"]], n = 30),\n ",
              " c(0.43577, 0.03743, 0.43175, 0.95758, 0.88775, 0.63998, 0.6",
-             "1884,\n0.33343, 0.34675, 0.39849, 0.78469, 0.67728, 0.17126,",
-             " 0.26109,\n0.67561, 0.98282, 0.75954, 0.56649, 0.84969, 0.18",
-             "947, 0.27129,\n0.6932, 0.24054, 0.04299, 0.14048, 0.19741, 0",
-             ".71936, 0.00788,\n0.37549, 0.00157),\n  tolerance = 1e-4)"),
+             "1884, \n    0.33343, 0.34675, 0.39849, 0.78469, 0.67728, 0.1",
+             "7126, 0.26109, \n    0.67561, 0.98282, 0.75954, 0.56649, 0.8",
+             "4969, 0.18947, 0.27129, \n    0.6932, 0.24054, 0.04299, 0.14",
+             "048, 0.19741, 0.71936, 0.00788, \n    0.37549, 0.00157),\n  ",
+             "tolerance = 1e-4)"),
       "# Testing column names",
       "expect_equal(\n  names(long_df),\n  c(\"a\", \"b\"),\n  fixed = TRUE)",
       "# Testing column classes",
